#!/bin/sh

if [ "$#" != "2" ]
 then
  echo "Usage:"
  echo "$0 LEVEL1_HDF_FILENAME OUTPUT_FILE.csv"
  echo
  echo "This will produce a CSV file of band no vs. wavelength centre vs. wavelength half-bandwidth"
  echo "Only for use on CCD sensors (CASI, Eagle, Hawk), not ATM"
  echo "Requires azexhdf to be in the path"
  exit
fi

azexhdf -vn CAwavc -vf /tmp/wavc.txt -h $1 > /dev/null
if [ "$?" == "127" ]
 then
  echo azexhdf command failed - is it in the PATH?
  exit 1
fi

azexhdf -vn CAwavh -vf /tmp/wavh.txt -h $1 > /dev/null
if [ "$?" == "127" ]
 then
  echo azexhdf command failed - is it in the PATH?
  exit 1
fi

cat /tmp/wavc.txt | tr ' ' \\n | tail -n +2 > /tmp/wavc-transposed.txt
cat /tmp/wavh.txt | tr ' ' \\n | tail -n +2 > /tmp/wavh-transposed.txt

echo '"Band number","Wavelength centre frequency (nm)","Wavelength half-bandwidth (nm)"' > $2

paste /tmp/wavc-transposed.txt /tmp/wavh-transposed.txt | cat -n | sed -e 's/^\s*//' | sed -e 's/\s\s*/,/g' >> $2

rm -f /tmp/wavc.txt /tmp/wavh.txt /tmp/wavc-transposed.txt /tmp/wavh-transposed.txt
